aboutsummaryrefslogtreecommitdiffstats
path: root/Compiler.h
diff options
context:
space:
mode:
Diffstat (limited to 'Compiler.h')
-rw-r--r--Compiler.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/Compiler.h b/Compiler.h
index 073721e0..ea05f38e 100644
--- a/Compiler.h
+++ b/Compiler.h
@@ -43,12 +43,13 @@ private:
void initializeContext(ContractDefinition const& _contract,
std::map<ContractDefinition const*, bytes const*> const& _contracts);
/// Adds the code that is run at creation time. Should be run after exchanging the run-time context
- /// with a new and initialized context.
- /// adds the constructor code.
+ /// with a new and initialized context. Adds the constructor code.
void packIntoContractCreator(ContractDefinition const& _contract, CompilerContext const& _runtimeContext);
+ void appendBaseConstructorCall(FunctionDefinition const& _constructor,
+ std::vector<ASTPointer<Expression>> const& _arguments);
void appendConstructorCall(FunctionDefinition const& _constructor);
- /// Recursively searches the call graph and returns all functions needed by the constructor (including itself).
- std::set<FunctionDefinition const*> getFunctionsNeededByConstructor(FunctionDefinition const& _constructor);
+ /// Recursively searches the call graph and returns all functions referenced inside _nodes.
+ std::set<FunctionDefinition const*> getFunctionsCalled(std::set<ASTNode const*> const& _nodes);
void appendFunctionSelector(ContractDefinition const& _contract);
/// Creates code that unpacks the arguments for the given function, from memory if
/// @a _fromMemory is true, otherwise from call data. @returns the size of the data in bytes.